@@ -36,12 +36,7 @@
 #' @examples
 #' # sample data set, imported from SPSS.
 #' data(efc)
-#'
-#' \dontrun{
-#' library(sjPlot)
-#' sjt.frq(efc$e42dep)
-#' sjt.frq(data.frame(efc$e42dep, efc$e16sex))}
-#'
+#' frq(efc$e42dep)
 #'
 #' # manually set value and variable labels
 #' dummy <- sample(1:4, 40, replace = TRUE)
@@ -110,7 +105,7 @@ set_label <- function(x, lab, attr.string = NULL) {
         if (is.data.frame(x)) cnames <- colnames(x)
 
         # iterate all columns / list elements
-        for (i in 1:nvars) {
+        for (i in seq_len(nvars)) {
           if (is_empty(lab[i])) {
             # empty label value means, remove
             # the label attribute
